@@ -14,6 +14,20 @@ XenaQuery <- function(x) {
   use_hiplot <- getOption("use_hiplot", default = FALSE)
 
   data_list <- UCSCXenaTools::XenaData
+
+  if (use_hiplot) {
+      # Check website status
+      use_hiplot <- tryCatch(
+          {
+              httr::http_error("https://xena-ucscpublic.hiplot.com.cn")
+              TRUE
+          },
+          error = function(e) {
+              message("The hiplot server may down, we will not use it for now.")
+              FALSE
+          }
+      )
+  }
   if (use_hiplot) {
     message("Use hiplot server (China) for mirrored data hubs (set 'options(use_hiplot = FALSE)' to disable it)")
     data_list$XenaHosts <- .xena_mirror_map_rv[data_list$XenaHosts]
@@ -54,7 +68,8 @@ http_error2 <- function(url, max_try = 3L, ...) {
     },
     error = function(e) {
       if (max_try == 1) {
-        stop("Tried 3 times but failed, please check your internet connection!")
+        message("Tried 3 times but failed, please check your internet connection!")
+        invisible(NULL)
       } else {
         http_error2(url, max_try - 1L)
       }
